@@ -1,7 +1,7 @@
 import asyncio
 import logging
 from datetime import datetime
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Callable, Optional
 
 from bleak import BleakClient
 from cryptography.hazmat.primitives import cmac
@@ -79,7 +79,6 @@ class CHSesame2(CHSesameLock):
     def __init__(self) -> None:
         """SESAME3 Device Specific Implementation."""
         super().__init__()
-        self.setProductModel(CHProductModel.SS2)
         self._rxBuffer = CHSesame2BleReceiver()
         self._txBuffer: Optional[CHSesame2BleTransmiter] = None
         self._mechStatus: Optional[CHSesame2MechStatus] = None
