@@ -1,7 +1,7 @@
 import asyncio
 import logging
 from datetime import datetime
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Callable, Optional
 
 from bleak import BleakClient
 from cryptography.hazmat.primitives import cmac
@@ -80,7 +80,6 @@ class CHSesameBot(CHSesameLock):
     def __init__(self) -> None:
         """SESAME bot Device Specific Implementation."""
         super().__init__()
-        self.setProductModel(CHProductModel.SesameBot1)
         self._rxBuffer = CHSesame2BleReceiver()
         self._txBuffer: Optional[CHSesame2BleTransmiter] = None
         self._mechStatus: Optional[CHSesameBotMechStatus] = None
